==> get-music-lizhanqi-0.0.66.tar.gz: get-music-lizhanqi-0.0.66/README.md <==
## 更新记录
- 2022-07-11 完成v0.0.65版，修复酷狗音乐、qq音乐、5sing下载歌词乱码和无法下载等问题
- 2022-06-11 完成v0.0.64版，修复酷狗音乐下载部分音乐时的错误
- 2022-06-11 完成v0.0.63版，开发权限开放！支持您在代码中调用该模块import get_music具体可以用多少个接口主要看dir(get_music)有什么，比如有kugou，那么可以这样用kugou=get_music.kugou()创建名为kugou的对象，然后dir(kugou)可以查看对象能进行的操作，kugou.search(songname),这是搜索，需要传递一个songname也就是歌曲名字，会返回三个列表类型的数据，包括歌曲名，歌手名，及歌曲在该平台的id号（url），如果是id号的话需要配合kugou.get_music_url(id)用这个方法会解析到真实的歌曲下载地址
- 2022-06-02 完成v0.0.62版，命令行支持向上翻页键入-1查看前一页的歌曲
- 2022-05-20 完成v0.0.59版，让您使用时更加稳定
- 2022-05-20 完成v0.0.58版，支持get-music -t 唤醒gui窗口进行下载，目前在win10上已经可以正常使用，但是没有为该gui添加下载进度条，使用的是python自带的tkinter框架
- 2022-05-13 完成v0.0.57版,全面支持下载歌词和封面，get-music -l 既下载歌曲又下载歌词,get-music -p 既下载歌曲又下载封面，get-music -lp既下载歌曲又同时下载歌词和封面
- 2022-05-12 完成v0.0.55版，全新架构了一下程序，使用面向对象编程，并新增一听接口，5sing原唱，5sing翻唱，支持翻页操作输入0即可实现翻页，全部接口都同时支持多个同时下载，不支持断点续传（注意网络环境哦），同时get-music -r的接口支持kg,kw,qq,wy,migu,bd,1ting,fc,yc
- 2022-05-10 完成v0.0.54版，修复qpython中无法下载的问题，这个bug居然是file关键字的问题（qpython的关键字，至于是不是python3.6的那就不得而知喽），我把它拿来当变量了，sorry
- 2022-05-04 完成v0.0.53版，完善批量下载机制和操作手册，更新MD文档
- 2022-05-02 完成v0.0.52版，更新输出格式不再采用tqdm第三库，将适配python3.0全版本，输出将采用自己的算法，使效率更高，修复酷狗音乐数据返回慢的问题
- 2022-04-30 完成v0.0.47版,更新输出格式，不至于输出格式眼花缭乱
- 2022-04-28 完成v0.0.46版，更新进度条颜色为紫色，支持python3.7及以上
- 2022-04-27 完成v0.0.45版，修复咪咕音乐的错误
- 2022-04-27 完成v0.0.44版，修复v0.0.28的搜索bug，支持python2.9版本及以上
- 2022-04-27 完成v0.0.33版，修复返回数据一致的bug（调试时的bug，忘记改回了。{{{(>_<)}}}）
- 2022-04-26 完成v0.0.32版，完善MD文档，适配多个平台，支持get-music -r 批量下载（具体用法请get-music help程序会有详细说明）
- 2022-04-25 完成v0.0.28版，最后一版适配python2.9-python3.7以下的版本，无进度条，但是功能正常使用
- 2022-04-25 完成v0.0.27版,新增下载进度条，加快咪咕音乐的搜索效率,修改咪咕音乐的下载的错误，修复搜索结果为空的异常
- 2022-04-14 完成v0.0.21版，修复千千静听（百度音乐）无法下载封面和歌词的bug
- 2022-04-12 完成v0.0.20版，支持百度音乐(千千静听),支持-help（查看帮助），-v（查看当前版本）
- 2022-04-11 完成v0.0.11版，支持咪咕音乐
- 2022-04-10 完成v0.0.9版，更新算法，使时间复杂度更低,并支持酷我音乐
- 2022-04-09 完成v0.0.5版，支持QQ音乐
- 2022-04-09 完成v0.0.1版，支持酷狗和网易云

## THE END
- 本脚本仅支持学习使用，如有发现有任何商业用途，一经发现您将受到法律责任。
- 本程序使用的接口全部来源于网络，切不可有任何商业用途，或我程序中有涉及你公司利益的，你可以联系我，我会及时删除源代码，并不再更新。
- **禁止将本工具用于商业用途**，如产生法律纠纷与本人无关，如有侵权，请联系我删除。
- 项目创建者：李展旗
- 项目维护者：李展旗
- 维护者邮箱：3101978435@qq.com

## 用爱发电
- 维护不易，欢迎扫描投币二维码:<http://img.lizhanqi.xyz/wepay.jpg>

## LICENSE

[MIT License](https://github.com/lzq-hopego/get-music-lizhanqi/tree/main/LICENSE)

==> get-music-lizhanqi-0.0.68.tar.gz: get-music-lizhanqi-0.0.68/README.md <==
## 更新记录
- 2022-08-06 完成v0.0.68版，修复酷狗音乐
- 2022-07-22 完成v0.0.67版，修复咪咕接口
- 2022-07-11 完成v0.0.66版，修复已知bug
- 2022-07-11 完成v0.0.65版，修复酷狗音乐、qq音乐、5sing下载歌词乱码和无法下载等问题
- 2022-06-11 完成v0.0.64版，修复酷狗音乐下载部分音乐时的错误
- 2022-06-11 完成v0.0.63版，开发权限开放！支持您在代码中调用该模块import get_music具体可以用多少个接口主要看dir(get_music)有什么，比如有kugou，那么可以这样用kugou=get_music.kugou()创建名为kugou的对象，然后dir(kugou)可以查看对象能进行的操作，kugou.search(songname),这是搜索，需要传递一个songname也就是歌曲名字，会返回三个列表类型的数据，包括歌曲名，歌手名，及歌曲在该平台的id号（url），如果是id号的话需要配合kugou.get_music_url(id)用这个方法会解析到真实的歌曲下载地址
- 2022-06-02 完成v0.0.62版，命令行支持向上翻页键入-1查看前一页的歌曲
- 2022-05-20 完成v0.0.59版，让您使用时更加稳定
- 2022-05-20 完成v0.0.58版，支持get-music -t 唤醒gui窗口进行下载，目前在win10上已经可以正常使用，但是没有为该gui添加下载进度条，使用的是python自带的tkinter框架
- 2022-05-13 完成v0.0.57版,全面支持下载歌词和封面，get-music -l 既下载歌曲又下载歌词,get-music -p 既下载歌曲又下载封面，get-music -lp既下载歌曲又同时下载歌词和封面
- 2022-05-12 完成v0.0.55版，全新架构了一下程序，使用面向对象编程，并新增一听接口，5sing原唱，5sing翻唱，支持翻页操作输入0即可实现翻页，全部接口都同时支持多个同时下载，不支持断点续传（注意网络环境哦），同时get-music -r的接口支持kg,kw,qq,wy,migu,bd,1ting,fc,yc
- 2022-05-10 完成v0.0.54版，修复qpython中无法下载的问题，这个bug居然是file关键字的问题（qpython的关键字，至于是不是python3.6的那就不得而知喽），我把它拿来当变量了，sorry
- 2022-05-04 完成v0.0.53版，完善批量下载机制和操作手册，更新MD文档
- 2022-05-02 完成v0.0.52版，更新输出格式不再采用tqdm第三库，将适配python3.0全版本，输出将采用自己的算法，使效率更高，修复酷狗音乐数据返回慢的问题
- 2022-04-30 完成v0.0.47版,更新输出格式，不至于输出格式眼花缭乱
- 2022-04-28 完成v0.0.46版，更新进度条颜色为紫色，支持python3.7及以上
- 2022-04-27 完成v0.0.45版，修复咪咕音乐的错误
- 2022-04-27 完成v0.0.44版，修复v0.0.28的搜索bug，支持python2.9版本及以上
- 2022-04-27 完成v0.0.33版，修复返回数据一致的bug（调试时的bug，忘记改回了。{{{(>_<)}}}）
- 2022-04-26 完成v0.0.32版，完善MD文档，适配多个平台，支持get-music -r 批量下载（具体用法请get-music help程序会有详细说明）
- 2022-04-25 完成v0.0.28版，最后一版适配python2.9-python3.7以下的版本，无进度条，但是功能正常使用
- 2022-04-25 完成v0.0.27版,新增下载进度条，加快咪咕音乐的搜索效率,修改咪咕音乐的下载的错误，修复搜索结果为空的异常
- 2022-04-14 完成v0.0.21版，修复千千静听（百度音乐）无法下载封面和歌词的bug
- 2022-04-12 完成v0.0.20版，支持百度音乐(千千静听),支持-help（查看帮助），-v（查看当前版本）
- 2022-04-11 完成v0.0.11版，支持咪咕音乐
- 2022-04-10 完成v0.0.9版，更新算法，使时间复杂度更低,并支持酷我音乐
- 2022-04-09 完成v0.0.5版，支持QQ音乐
- 2022-04-09 完成v0.0.1版，支持酷狗和网易云（该版本源码已删除）

## THE END
- 本脚本仅支持学习使用，如有发现有任何商业用途，一经发现您将受到法律责任。
- 本程序使用的接口全部来源于网络，切不可有任何商业用途，或我程序中有涉及你公司利益的，你可以联系我，我会及时删除源代码，并不再更新。
- **禁止将本工具用于商业用途**，如产生法律纠纷与本人无关，如有侵权，请联系我删除。
- 项目创建者：李展旗
- 项目维护者：李展旗
- 维护者邮箱：3101978435@qq.com
